summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sys/altq/altq_cbq.c8
-rw-r--r--sys/altq/altq_hfsc.c8
-rw-r--r--sys/altq/altq_priq.c8
-rw-r--r--sys/altq/altq_rmclass.c12
-rw-r--r--sys/altq/altq_rmclass_debug.h4
-rw-r--r--sys/altq/altq_subr.c10
-rw-r--r--sys/kern/init_main.c4
-rw-r--r--sys/kern/uipc_socket.c4
-rw-r--r--sys/net/bpf.c32
-rw-r--r--sys/net/bridgestp.c6
-rw-r--r--sys/net/if.c14
-rw-r--r--sys/net/if.h4
-rw-r--r--sys/net/if_arcsubr.c8
-rw-r--r--sys/net/if_atmsubr.c8
-rw-r--r--sys/net/if_bridge.c18
-rw-r--r--sys/net/if_enc.c4
-rw-r--r--sys/net/if_ethersubr.c10
-rw-r--r--sys/net/if_faith.c4
-rw-r--r--sys/net/if_fddisubr.c6
-rw-r--r--sys/net/if_gif.c4
-rw-r--r--sys/net/if_gre.c4
-rw-r--r--sys/net/if_loop.c10
-rw-r--r--sys/net/if_pflog.c4
-rw-r--r--sys/net/if_pfsync.c4
-rw-r--r--sys/net/if_ppp.c40
-rw-r--r--sys/net/if_pppoe.c6
-rw-r--r--sys/net/if_spppsubr.c35
-rw-r--r--sys/net/if_tokensubr.c6
-rw-r--r--sys/net/if_trunk.c6
-rw-r--r--sys/net/if_tun.c28
-rw-r--r--sys/net/if_vlan.c7
-rw-r--r--sys/net/pf_ioctl.c6
-rw-r--r--sys/net80211/ieee80211_output.c4
-rw-r--r--sys/netatalk/aarp.c6
-rw-r--r--sys/netatalk/at_control.c4
-rw-r--r--sys/netatalk/ddp_input.c6
-rw-r--r--sys/netbt/bt_input.c4
-rw-r--r--sys/netbt/hci_raw.c6
-rw-r--r--sys/netinet/if_ether.c4
-rw-r--r--sys/netinet/in.c4
-rw-r--r--sys/netinet/ip_gre.c6
-rw-r--r--sys/netinet/ip_input.c4
-rw-r--r--sys/netinet/ip_ipip.c4
-rw-r--r--sys/netinet/ip_output.c4
-rw-r--r--sys/netinet/ipsec_input.c8
-rw-r--r--sys/netinet/tcp_subr.c4
-rw-r--r--sys/netinet6/in6.c4
-rw-r--r--sys/netinet6/ip6_input.c4
-rw-r--r--sys/netipx/ipx.c4
-rw-r--r--sys/netipx/ipx_input.c4
-rw-r--r--sys/netipx/ipx_ip.c4
-rw-r--r--sys/netipx/ipx_pcb.c4
-rw-r--r--sys/netnatm/natm.c10
-rw-r--r--sys/netnatm/natm_pcb.c6
54 files changed, 220 insertions, 220 deletions
diff --git a/sys/altq/altq_hfsc.c b/sys/altq/altq_hfsc.c
index fc58f4af129..cc6d752820d 100644
--- a/sys/altq/altq_hfsc.c
+++ b/sys/altq/altq_hfsc.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: altq_hfsc.c,v 1.22 2005/10/17 08:43:35 henning Exp $ */
+/* $OpenBSD: altq_hfsc.c,v 1.23 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: altq_hfsc.c,v 1.17 2002/11/29 07:48:33 kjc Exp $ */
/*
@@ -136,7 +136,7 @@ hfsc_pfattach(struct pf_altq *a)
if ((ifp = ifunit(a->ifname)) == NULL || a->altq_disc == NULL)
return (EINVAL);
- s = splimp();
+ s = splnet();
error = altq_attach(&ifp->if_snd, ALTQT_HFSC, a->altq_disc,
hfsc_enqueue, hfsc_dequeue, hfsc_request, NULL, NULL);
splx(s);
@@ -446,7 +446,7 @@ hfsc_class_create(struct hfsc_if *hif, struct service_curve *rsc,
cl->cl_hif = hif;
cl->cl_parent = parent;
- s = splimp();
+ s = splnet();
hif->hif_classes++;
/*
@@ -525,7 +525,7 @@ hfsc_class_destroy(struct hfsc_class *cl)
if (is_a_parent_class(cl))
return (EBUSY);
- s = splimp();
+ s = splnet();
if (!qempty(cl->cl_q))
hfsc_purgeq(cl);
diff --git a/sys/altq/altq_priq.c b/sys/altq/altq_priq.c
index 3f04e81a35c..e6d6a83c0ba 100644
--- a/sys/altq/altq_priq.c
+++ b/sys/altq/altq_priq.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: altq_priq.c,v 1.18 2005/10/17 08:43:35 henning Exp $ */
+/* $OpenBSD: altq_priq.c,v 1.19 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: altq_priq.c,v 1.1 2000/10/18 09:15:23 kjc Exp $ */
/*
* Copyright (C) 2000
@@ -75,7 +75,7 @@ priq_pfattach(struct pf_altq *a)
if ((ifp = ifunit(a->ifname)) == NULL || a->altq_disc == NULL)
return (EINVAL);
- s = splimp();
+ s = splnet();
error = altq_attach(&ifp->if_snd, ALTQT_PRIQ, a->altq_disc,
priq_enqueue, priq_dequeue, priq_request, NULL, NULL);
splx(s);
@@ -253,7 +253,7 @@ priq_class_create(struct priq_if *pif, int pri, int qlimit, int flags, int qid)
if ((cl = pif->pif_classes[pri]) != NULL) {
/* modify the class instead of creating a new one */
- s = splimp();
+ s = splnet();
if (!qempty(cl->cl_q))
priq_purgeq(cl);
splx(s);
@@ -354,7 +354,7 @@ priq_class_destroy(struct priq_class *cl)
struct priq_if *pif;
int s, pri;
- s = splimp();
+ s = splnet();
if (!qempty(cl->cl_q))
priq_purgeq(cl);
diff --git a/sys/altq/altq_rmclass_debug.h b/sys/altq/altq_rmclass_debug.h
index a8811057b99..f5ce3203f94 100644
--- a/sys/altq/altq_rmclass_debug.h
+++ b/sys/altq/altq_rmclass_debug.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: altq_rmclass_debug.h,v 1.2 2002/11/26 01:03:34 henning Exp $ */
+/* $OpenBSD: altq_rmclass_debug.h,v 1.3 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: altq_rmclass_debug.h,v 1.2 2000/02/22 14:00:35 itojun Exp $ */
/*
@@ -82,7 +82,7 @@ extern int cbqtrace_count;
} \
}
-#define LOCK_TRACE() splimp()
+#define LOCK_TRACE() splnet()
#define UNLOCK_TRACE(x) splx(x)
#define CBQTRACE(func, act, obj) { \
diff --git a/sys/altq/altq_subr.c b/sys/altq/altq_subr.c
index 89fc5071989..098d8851af7 100644
--- a/sys/altq/altq_subr.c
+++ b/sys/altq/altq_subr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: altq_subr.c,v 1.19 2004/07/28 17:15:12 tholo Exp $ */
+/* $OpenBSD: altq_subr.c,v 1.20 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: altq_subr.c,v 1.11 2002/01/11 08:11:49 kjc Exp $ */
/*
@@ -155,7 +155,7 @@ altq_enable(ifq)
if (ALTQ_IS_ENABLED(ifq))
return 0;
- s = splimp();
+ s = splnet();
IFQ_PURGE(ifq);
ASSERT(ifq->ifq_len == 0);
ifq->altq_flags |= ALTQF_ENABLED;
@@ -175,7 +175,7 @@ altq_disable(ifq)
if (!ALTQ_IS_ENABLED(ifq))
return 0;
- s = splimp();
+ s = splnet();
IFQ_PURGE(ifq);
ASSERT(ifq->ifq_len == 0);
ifq->altq_flags &= ~(ALTQF_ENABLED|ALTQF_CLASSIFY);
@@ -321,7 +321,7 @@ tbr_timeout(arg)
int active, s;
active = 0;
- s = splimp();
+ s = splnet();
for (ifp = TAILQ_FIRST(&ifnet); ifp; ifp = TAILQ_NEXT(ifp, if_list)) {
if (!TBR_IS_ENABLED(&ifp->if_snd))
continue;
@@ -423,7 +423,7 @@ altq_pfdetach(struct pf_altq *a)
if (a->altq_disc == NULL || a->altq_disc != ifp->if_snd.altq_disc)
return (0);
- s = splimp();
+ s = splnet();
if (ALTQ_IS_ENABLED(&ifp->if_snd))
error = altq_disable(&ifp->if_snd);
if (error == 0)
diff --git a/sys/kern/init_main.c b/sys/kern/init_main.c
index ac9dac3a46b..573791b6eed 100644
--- a/sys/kern/init_main.c
+++ b/sys/kern/init_main.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: init_main.c,v 1.128 2006/01/01 11:54:31 miod Exp $ */
+/* $OpenBSD: init_main.c,v 1.129 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: init_main.c,v 1.84.4.1 1996/06/02 09:08:06 mrg Exp $ */
/*
@@ -380,7 +380,7 @@ main(void *framep)
* Initialize protocols. Block reception of incoming packets
* until everything is ready.
*/
- s = splimp();
+ s = splnet();
ifinit();
domaininit();
if_attachdomain();
diff --git a/sys/kern/uipc_socket.c b/sys/kern/uipc_socket.c
index 6b0a5d685c9..64848625731 100644
--- a/sys/kern/uipc_socket.c
+++ b/sys/kern/uipc_socket.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: uipc_socket.c,v 1.62 2006/01/05 05:05:06 jsg Exp $ */
+/* $OpenBSD: uipc_socket.c,v 1.63 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: uipc_socket.c,v 1.21 1996/02/04 02:17:52 christos Exp $ */
/*
@@ -951,7 +951,7 @@ sorflush(struct socket *so)
sb->sb_flags |= SB_NOINTR;
(void) sblock(sb, M_WAITOK);
- s = splimp();
+ s = splnet();
socantrcvmore(so);
sbunlock(sb);
asb = *sb;
diff --git a/sys/net/bridgestp.c b/sys/net/bridgestp.c
index 73304bfbed5..42cc5f88e43 100644
--- a/sys/net/bridgestp.c
+++ b/sys/net/bridgestp.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: bridgestp.c,v 1.19 2005/10/12 15:17:18 markus Exp $ */
+/* $OpenBSD: bridgestp.c,v 1.20 2006/03/04 22:40:15 brad Exp $ */
/*
* Copyright (c) 2000 Jason L. Wright (jason@thought.net)
@@ -231,7 +231,7 @@ bstp_send_config_bpdu(bif, cu)
struct bstp_cbpdu bpdu;
int s, error;
- s = splimp();
+ s = splnet();
ifp = bif->ifp;
arp = (struct arpcom *)ifp;
@@ -418,7 +418,7 @@ bstp_transmit_tcn(sc)
bpdu.tbu_bpdutype = BSTP_MSGTYPE_TCN;
bcopy(&bpdu, m->m_data + sizeof(*eh), sizeof(bpdu));
- s = splimp();
+ s = splnet();
IFQ_ENQUEUE(&ifp->if_snd, m, NULL, error);
if (error == 0 && (ifp->if_flags & IFF_OACTIVE) == 0)
(*ifp->if_start)(ifp);
diff --git a/sys/net/if.c b/sys/net/if.c
index 4cd166fb3c9..ccc0093c184 100644
--- a/sys/net/if.c
+++ b/sys/net/if.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if.c,v 1.143 2006/02/09 00:05:55 reyk Exp $ */
+/* $OpenBSD: if.c,v 1.144 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if.c,v 1.35 1996/05/07 05:26:04 thorpej Exp $ */
/*
@@ -500,7 +500,7 @@ if_detach(struct ifnet *ifp)
{
struct ifaddr *ifa;
struct ifg_list *ifg;
- int i, s = splimp();
+ int i, s = splnet();
struct radix_node_head *rnh;
struct domain *dp;
@@ -732,7 +732,7 @@ if_clone_destroy(const char *name)
return (EOPNOTSUPP);
if (ifp->if_flags & IFF_UP) {
- s = splimp();
+ s = splnet();
if_down(ifp);
splx(s);
}
@@ -1148,7 +1148,7 @@ if_slowtimo(void *arg)
{
struct timeout *to = (struct timeout *)arg;
struct ifnet *ifp;
- int s = splimp();
+ int s = splnet();
TAILQ_FOREACH(ifp, &ifnet, if_list) {
if (ifp->if_timer == 0 || --ifp->if_timer)
@@ -1241,12 +1241,12 @@ ifioctl(struct socket *so, u_long cmd, caddr_t data, struct proc *p)
if ((error = suser(p, 0)) != 0)
return (error);
if (ifp->if_flags & IFF_UP && (ifr->ifr_flags & IFF_UP) == 0) {
- int s = splimp();
+ int s = splnet();
if_down(ifp);
splx(s);
}
if (ifr->ifr_flags & IFF_UP && (ifp->if_flags & IFF_UP) == 0) {
- int s = splimp();
+ int s = splnet();
if_up(ifp);
splx(s);
}
@@ -1374,7 +1374,7 @@ ifioctl(struct socket *so, u_long cmd, caddr_t data, struct proc *p)
return (ENODEV);
}
if (ifp->if_flags & IFF_UP) {
- int s = splimp();
+ int s = splnet();
ifp->if_flags &= ~IFF_UP;
(*ifp->if_ioctl)(ifp, SIOCSIFFLAGS, (caddr_t)&ifr);
ifp->if_flags |= IFF_UP;
diff --git a/sys/net/if.h b/sys/net/if.h
index 4bab20af4c1..efb7bdd13d9 100644
--- a/sys/net/if.h
+++ b/sys/net/if.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: if.h,v 1.77 2006/02/09 00:05:55 reyk Exp $ */
+/* $OpenBSD: if.h,v 1.78 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if.h,v 1.23 1996/05/07 02:40:27 thorpej Exp $ */
/*
@@ -283,7 +283,7 @@ struct ifnet { /* and the entries */
* Output queues (ifp->if_snd) and internetwork datagram level (pup level 1)
* input routines have queues of messages stored on ifqueue structures
* (defined above). Entries are added to and deleted from these structures
- * by these macros, which should be called with ipl raised to splimp().
+ * by these macros, which should be called with ipl raised to splnet().
*/
#define IF_QFULL(ifq) ((ifq)->ifq_len >= (ifq)->ifq_maxlen)
#define IF_DROP(ifq) ((ifq)->ifq_drops++)
diff --git a/sys/net/if_arcsubr.c b/sys/net/if_arcsubr.c
index e0fd311a8e8..6d4851d3af2 100644
--- a/sys/net/if_arcsubr.c
+++ b/sys/net/if_arcsubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_arcsubr.c,v 1.21 2004/06/21 23:50:36 tholo Exp $ */
+/* $OpenBSD: if_arcsubr.c,v 1.22 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_arcsubr.c,v 1.8 1996/05/07 02:40:29 thorpej Exp $ */
/*
@@ -207,7 +207,7 @@ arc_output(ifp, m0, dst, rt0)
ah->arc_seqid = ac->ac_seqid;
len = m->m_pkthdr.len;
- s = splimp();
+ s = splnet();
/*
* Queue message on interface, and start output if
* interface not yet active.
@@ -266,7 +266,7 @@ arc_output(ifp, m0, dst, rt0)
}
len = m->m_pkthdr.len;
- s = splimp();
+ s = splnet();
/*
* Queue message on interface, and start output if interface
* not yet active.
@@ -508,7 +508,7 @@ arc_input(ifp, m)
return;
}
- s = splimp();
+ s = splnet();
IF_INPUT_ENQUEUE(inq, m);
splx(s);
}
diff --git a/sys/net/if_atmsubr.c b/sys/net/if_atmsubr.c
index 12b6d73e279..0594b071359 100644
--- a/sys/net/if_atmsubr.c
+++ b/sys/net/if_atmsubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_atmsubr.c,v 1.25 2005/09/30 02:39:24 brad Exp $ */
+/* $OpenBSD: if_atmsubr.c,v 1.26 2006/03/04 22:40:15 brad Exp $ */
/*
*
@@ -233,7 +233,7 @@ atm_output(ifp, m0, dst, rt0)
* not yet active.
*/
len = m->m_pkthdr.len;
- s = splimp();
+ s = splnet();
IFQ_ENQUEUE(&ifp->if_snd, m, NULL, error);
if (error) {
splx(s);
@@ -275,7 +275,7 @@ atm_input(ifp, ah, m, rxhand)
if (rxhand) {
#ifdef NATM
struct natmpcb *npcb = rxhand;
- s = splimp(); /* in case 2 atm cards @ diff lvls */
+ s = splnet(); /* in case 2 atm cards @ diff lvls */
npcb->npcb_inq++; /* count # in queue */
splx(s);
schednetisr(NETISR_NATM);
@@ -330,7 +330,7 @@ atm_input(ifp, ah, m, rxhand)
}
}
- s = splimp();
+ s = splnet();
IF_INPUT_ENQUEUE(inq, m);
splx(s);
}
diff --git a/sys/net/if_bridge.c b/sys/net/if_bridge.c
index 0af05d429a8..0a74a12de73 100644
--- a/sys/net/if_bridge.c
+++ b/sys/net/if_bridge.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_bridge.c,v 1.149 2006/01/23 22:46:57 markus Exp $ */
+/* $OpenBSD: if_bridge.c,v 1.150 2006/03/04 22:40:15 brad Exp $ */
/*
* Copyright (c) 1999, 2000 Jason L. Wright (jason@thought.net)
@@ -963,7 +963,7 @@ bridge_output(struct ifnet *ifp, struct mbuf *m, struct sockaddr *sa,
src = (struct ether_addr *)&eh->ether_shost[0];
sc = (struct bridge_softc *)ifp->if_bridge;
- s = splimp();
+ s = splnet();
/*
* If bridge is down, but original output interface is up,
@@ -1113,7 +1113,7 @@ bridgeintr(void)
LIST_FOREACH(sc, &bridge_list, sc_list) {
for (;;) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&sc->sc_if.if_snd, m);
splx(s);
if (m == NULL)
@@ -1260,7 +1260,7 @@ bridgeintr_frame(struct bridge_softc *sc, struct mbuf *m)
*/
if ((m->m_flags & (M_BCAST | M_MCAST)) || dst_if == NULL) {
sc->sc_if.if_imcasts++;
- s = splimp();
+ s = splnet();
bridge_broadcast(sc, src_if, &eh, m);
splx(s);
return;
@@ -1302,7 +1302,7 @@ bridgeintr_frame(struct bridge_softc *sc, struct mbuf *m)
if ((len - ETHER_HDR_LEN) > dst_if->if_mtu)
bridge_fragment(sc, dst_if, &eh, m);
else {
- s = splimp();
+ s = splnet();
bridge_ifenqueue(sc, dst_if, m);
splx(s);
}
@@ -1375,7 +1375,7 @@ bridge_input(struct ifnet *ifp, struct ether_header *eh, struct mbuf *m)
if (mc == NULL)
return (m);
bcopy(eh, mtod(mc, caddr_t), ETHER_HDR_LEN);
- s = splimp();
+ s = splnet();
if (IF_QFULL(&sc->sc_if.if_snd)) {
m_freem(mc);
splx(s);
@@ -1455,7 +1455,7 @@ bridge_input(struct ifnet *ifp, struct ether_header *eh, struct mbuf *m)
if (m == NULL)
return (NULL);
bcopy(eh, mtod(m, caddr_t), ETHER_HDR_LEN);
- s = splimp();
+ s = splnet();
if (IF_QFULL(&sc->sc_if.if_snd)) {
m_freem(m);
splx(s);
@@ -2530,7 +2530,7 @@ bridge_fragment(struct bridge_softc *sc, struct ifnet *ifp,
(ifp->if_capabilities & IFCAP_VLAN_MTU) &&
((m->m_pkthdr.len - sizeof(struct ether_vlan_header)) <=
ifp->if_mtu)) {
- s = splimp();
+ s = splnet();
bridge_ifenqueue(sc, ifp, m);
splx(s);
return;
@@ -2598,7 +2598,7 @@ bridge_fragment(struct bridge_softc *sc, struct ifnet *ifp,
}
len = m->m_pkthdr.len;
bcopy(eh, mtod(m, caddr_t), sizeof(*eh));
- s = splimp();
+ s = splnet();
error = bridge_ifenqueue(sc, ifp, m);
if (error) {
splx(s);
diff --git a/sys/net/if_enc.c b/sys/net/if_enc.c
index 9d2afcff123..4dfc5434410 100644
--- a/sys/net/if_enc.c
+++ b/sys/net/if_enc.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_enc.c,v 1.42 2005/06/08 06:35:04 henning Exp $ */
+/* $OpenBSD: if_enc.c,v 1.43 2006/03/04 22:40:15 brad Exp $ */
/*
* The authors of this code are John Ioannidis (ji@tla.org),
* Angelos D. Keromytis (kermit@csd.uch.gr) and
@@ -123,7 +123,7 @@ struct ifnet *ifp;
for (;;)
{
- s = splimp();
+ s = splnet();
IF_DROP(&ifp->if_snd);
IF_DEQUEUE(&ifp->if_snd, m);
splx(s);
diff --git a/sys/net/if_ethersubr.c b/sys/net/if_ethersubr.c
index ee4bbf4c1d2..03370cd2e37 100644
--- a/sys/net/if_ethersubr.c
+++ b/sys/net/if_ethersubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_ethersubr.c,v 1.99 2005/11/03 20:00:18 reyk Exp $ */
+/* $OpenBSD: if_ethersubr.c,v 1.100 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_ethersubr.c,v 1.19 1996/05/07 02:40:30 thorpej Exp $ */
/*
@@ -450,7 +450,7 @@ ether_output(ifp0, m0, dst, rt0)
mflags = m->m_flags;
len = m->m_pkthdr.len;
- s = splimp();
+ s = splnet();
/*
* Queue message on interface, and start output if interface
* not yet active.
@@ -775,7 +775,7 @@ decapsulate:
}
}
- s = splimp();
+ s = splnet();
IF_INPUT_ENQUEUE(inq, m);
splx(s);
}
@@ -1059,7 +1059,7 @@ ether_addmulti(ifr, ac)
struct ether_multi *enm;
u_char addrlo[ETHER_ADDR_LEN];
u_char addrhi[ETHER_ADDR_LEN];
- int s = splimp(), error;
+ int s = splnet(), error;
error = ether_multiaddr(&ifr->ifr_addr, addrlo, addrhi);
if (error != 0) {
@@ -1120,7 +1120,7 @@ ether_delmulti(ifr, ac)
struct ether_multi *enm;
u_char addrlo[ETHER_ADDR_LEN];
u_char addrhi[ETHER_ADDR_LEN];
- int s = splimp(), error;
+ int s = splnet(), error;
error = ether_multiaddr(&ifr->ifr_addr, addrlo, addrhi);
if (error != 0) {
diff --git a/sys/net/if_faith.c b/sys/net/if_faith.c
index 2e66d742581..e61a9b191ef 100644
--- a/sys/net/if_faith.c
+++ b/sys/net/if_faith.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_faith.c,v 1.20 2006/01/04 06:04:42 canacar Exp $ */
+/* $OpenBSD: if_faith.c,v 1.21 2006/03/04 22:40:15 brad Exp $ */
/*
* Copyright (c) 1982, 1986, 1993
* The Regents of the University of California. All rights reserved.
@@ -180,7 +180,7 @@ faithoutput(ifp, m, dst, rt)
/* XXX do we need more sanity checks? */
m->m_pkthdr.rcvif = ifp;
- s = splimp();
+ s = splnet();
if (IF_QFULL(ifq)) {
IF_DROP(ifq);
m_freem(m);
diff --git a/sys/net/if_fddisubr.c b/sys/net/if_fddisubr.c
index d33a1b00821..d44036e0582 100644
--- a/sys/net/if_fddisubr.c
+++ b/sys/net/if_fddisubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_fddisubr.c,v 1.47 2005/10/17 08:43:35 henning Exp $ */
+/* $OpenBSD: if_fddisubr.c,v 1.48 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_fddisubr.c,v 1.5 1996/05/07 23:20:21 christos Exp $ */
/*
@@ -358,7 +358,7 @@ fddi_output(ifp0, m0, dst, rt0)
#endif
mflags = m->m_flags;
len = m->m_pkthdr.len;
- s = splimp();
+ s = splnet();
/*
* Queue message on interface, and start output if interface
* not yet active.
@@ -478,7 +478,7 @@ fddi_input(ifp, fh, m)
return;
}
- s = splimp();
+ s = splnet();
IF_INPUT_ENQUEUE(inq, m);
splx(s);
}
diff --git a/sys/net/if_gif.c b/sys/net/if_gif.c
index 7e67b83e1b0..f19474835e8 100644
--- a/sys/net/if_gif.c
+++ b/sys/net/if_gif.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_gif.c,v 1.33 2006/01/04 06:04:42 canacar Exp $ */
+/* $OpenBSD: if_gif.c,v 1.34 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: if_gif.c,v 1.43 2001/02/20 08:51:07 itojun Exp $ */
/*
@@ -166,7 +166,7 @@ gif_start(ifp)
#endif /* NBRIDGE */
for (;;) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&ifp->if_snd, m);
splx(s);
diff --git a/sys/net/if_gre.c b/sys/net/if_gre.c
index 7a94b29c29e..cf2a24a0c80 100644
--- a/sys/net/if_gre.c
+++ b/sys/net/if_gre.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_gre.c,v 1.38 2006/01/04 06:04:42 canacar Exp $ */
+/* $OpenBSD: if_gre.c,v 1.39 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_gre.c,v 1.9 1999/10/25 19:18:11 drochner Exp $ */
/*
@@ -432,7 +432,7 @@ gre_ioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
int error = 0;
struct proc *prc = curproc; /* XXX */
- s = splimp();
+ s = splnet();
switch(cmd) {
case SIOCSIFADDR:
ifp->if_flags |= IFF_UP;
diff --git a/sys/net/if_loop.c b/sys/net/if_loop.c
index d3556ef14e8..59c4f3d4922 100644
--- a/sys/net/if_loop.c
+++ b/sys/net/if_loop.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_loop.c,v 1.38 2006/01/04 06:04:42 canacar Exp $ */
+/* $OpenBSD: if_loop.c,v 1.39 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_loop.c,v 1.15 1996/05/07 02:40:33 thorpej Exp $ */
/*
@@ -277,7 +277,7 @@ looutput(ifp, m, dst, rt)
afp = mtod(m, int32_t *);
*afp = (int32_t)dst->sa_family;
- s = splimp();
+ s = splnet();
IFQ_ENQUEUE(&ifp->if_snd, m, NULL, error);
(*ifp->if_start)(ifp);
splx(s);
@@ -316,7 +316,7 @@ looutput(ifp, m, dst, rt)
m_freem(m);
return (EAFNOSUPPORT);
}
- s = splimp();
+ s = splnet();
if (IF_QFULL(ifq)) {
IF_DROP(ifq);
m_freem(m);
@@ -342,7 +342,7 @@ lo_altqstart(ifp)
int s, isr;
while (1) {
- s = splimp();
+ s = splnet();
IFQ_DEQUEUE(&ifp->if_snd, m);
splx(s);
if (m == NULL)
@@ -384,7 +384,7 @@ lo_altqstart(ifp)
return;
}
- s = splimp();
+ s = splnet();
if (IF_QFULL(ifq)) {
IF_DROP(ifq);
m_freem(m);
diff --git a/sys/net/if_pflog.c b/sys/net/if_pflog.c
index 548d0247c66..ee11c042de8 100644
--- a/sys/net/if_pflog.c
+++ b/sys/net/if_pflog.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_pflog.c,v 1.15 2005/07/31 03:52:18 pascoe Exp $ */
+/* $OpenBSD: if_pflog.c,v 1.16 2006/03/04 22:40:15 brad Exp $ */
/*
* The authors of this code are John Ioannidis (ji@tla.org),
* Angelos D. Keromytis (kermit@csd.uch.gr) and
@@ -123,7 +123,7 @@ pflogstart(struct ifnet *ifp)
int s;
for (;;) {
- s = splimp();
+ s = splnet();
IF_DROP(&ifp->if_snd);
IF_DEQUEUE(&ifp->if_snd, m);
splx(s);
diff --git a/sys/net/if_pfsync.c b/sys/net/if_pfsync.c
index 381d3999a6f..67ed402a2b1 100644
--- a/sys/net/if_pfsync.c
+++ b/sys/net/if_pfsync.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_pfsync.c,v 1.60 2006/02/20 20:12:14 damien Exp $ */
+/* $OpenBSD: if_pfsync.c,v 1.61 2006/03/04 22:40:15 brad Exp $ */
/*
* Copyright (c) 2002 Michael Shalayeff
@@ -158,7 +158,7 @@ pfsyncstart(struct ifnet *ifp)
int s;
for (;;) {
- s = splimp();
+ s = splnet();
IF_DROP(&ifp->if_snd);
IF_DEQUEUE(&ifp->if_snd, m);
splx(s);
diff --git a/sys/net/if_ppp.c b/sys/net/if_ppp.c
index 04b996a7918..38b9d10df16 100644
--- a/sys/net/if_ppp.c
+++ b/sys/net/if_ppp.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_ppp.c,v 1.43 2006/01/04 06:04:42 canacar Exp $ */
+/* $OpenBSD: if_ppp.c,v 1.44 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_ppp.c,v 1.39 1997/05/17 21:11:59 christos Exp $ */
/*
@@ -262,7 +262,7 @@ ppp_clone_create(ifc, unit)
#if NBPFILTER > 0
bpfattach(&sc->sc_bpf, &sc->sc_if, DLT_PPP, PPP_HDRLEN);
#endif
- s = splimp();
+ s = splnet();
LIST_INSERT_HEAD(&ppp_softc_list, sc, sc_list);
splx(s);
@@ -279,7 +279,7 @@ ppp_clone_destroy(ifp)
if (sc->sc_devp != NULL)
return (EBUSY);
- s = splimp();
+ s = splnet();
LIST_REMOVE(sc, sc_list);
splx(s);
@@ -443,7 +443,7 @@ pppioctl(sc, cmd, data, flag, p)
if (sc->sc_flags & SC_CCP_OPEN && !(flags & SC_CCP_OPEN))
ppp_ccp_closed(sc);
#endif
- splimp();
+ splnet();
sc->sc_flags = (sc->sc_flags & ~SC_MASK) | flags;
splx(s);
break;
@@ -509,7 +509,7 @@ pppioctl(sc, cmd, data, flag, p)
sc->sc_if.if_xname);
error = ENOBUFS;
}
- splimp();
+ splnet();
sc->sc_flags &= ~SC_COMP_RUN;
splx(s);
} else {
@@ -524,7 +524,7 @@ pppioctl(sc, cmd, data, flag, p)
sc->sc_if.if_xname);
error = ENOBUFS;
}
- splimp();
+ splnet();
sc->sc_flags &= ~SC_DECOMP_RUN;
splx(s);
}
@@ -593,7 +593,7 @@ pppioctl(sc, cmd, data, flag, p)
newcode = 0;
bp = (cmd == PPPIOCSPASS)? &sc->sc_pass_filt: &sc->sc_active_filt;
oldcode = bp->bf_insns;
- s = splimp();
+ s = splnet();
bp->bf_len = nbp->bf_len;
bp->bf_insns = newcode;
splx(s);
@@ -623,7 +623,7 @@ pppsioctl(ifp, cmd, data)
#ifdef PPP_COMPRESS
struct ppp_comp_stats *pcp;
#endif
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
case SIOCSIFFLAGS:
@@ -954,7 +954,7 @@ void
ppp_restart(sc)
struct ppp_softc *sc;
{
- int s = splimp();
+ int s = splnet();
sc->sc_flags &= ~SC_TBUSY;
schednetisr(NETISR_PPP);
@@ -1109,13 +1109,13 @@ pppintr()
LIST_FOREACH(sc, &ppp_softc_list, sc_list) {
if (!(sc->sc_flags & SC_TBUSY)
&& (IFQ_IS_EMPTY(&sc->sc_if.if_snd) == 0 || sc->sc_fastq.ifq_head)) {
- s2 = splimp();
+ s2 = splnet();
sc->sc_flags |= SC_TBUSY;
splx(s2);
(*sc->sc_start)(sc);
}
for (;;) {
- s2 = splimp();
+ s2 = splnet();
IF_DEQUEUE(&sc->sc_rawq, m);
splx(s2);
if (m == NULL)
@@ -1171,7 +1171,7 @@ ppp_ccp(sc, m, rcvd)
case CCP_TERMACK:
/* CCP must be going down - disable compression */
if (sc->sc_flags & SC_CCP_UP) {
- s = splimp();
+ s = splnet();
sc->sc_flags &= ~(SC_CCP_UP | SC_COMP_RUN | SC_DECOMP_RUN);
splx(s);
}
@@ -1187,7 +1187,7 @@ ppp_ccp(sc, m, rcvd)
&& (*sc->sc_xcomp->comp_init)
(sc->sc_xc_state, dp + CCP_HDRLEN, slen - CCP_HDRLEN,
sc->sc_unit, 0, sc->sc_flags & SC_DEBUG)) {
- s = splimp();
+ s = splnet();
sc->sc_flags |= SC_COMP_RUN;
splx(s);
}
@@ -1198,7 +1198,7 @@ ppp_ccp(sc, m, rcvd)
(sc->sc_rc_state, dp + CCP_HDRLEN, slen - CCP_HDRLEN,
sc->sc_unit, 0, sc->sc_mru,
sc->sc_flags & SC_DEBUG)) {
- s = splimp();
+ s = splnet();
sc->sc_flags |= SC_DECOMP_RUN;
sc->sc_flags &= ~(SC_DC_ERROR | SC_DC_FERROR);
splx(s);
@@ -1215,7 +1215,7 @@ ppp_ccp(sc, m, rcvd)
} else {
if (sc->sc_rc_state && (sc->sc_flags & SC_DECOMP_RUN)) {
(*sc->sc_rcomp->decomp_reset)(sc->sc_rc_state);
- s = splimp();
+ s = splnet();
sc->sc_flags &= ~SC_DC_ERROR;
splx(s);
}
@@ -1255,7 +1255,7 @@ ppppktin(sc, m, lost)
struct mbuf *m;
int lost;
{
- int s = splimp();
+ int s = splnet();
if (lost)
m->m_flags |= M_ERRMARK;
@@ -1301,7 +1301,7 @@ ppp_inproc(sc, m)
if (m->m_flags & M_ERRMARK) {
m->m_flags &= ~M_ERRMARK;
- s = splimp();
+ s = splnet();
sc->sc_flags |= SC_VJ_RESET;
splx(s);
}
@@ -1333,7 +1333,7 @@ ppp_inproc(sc, m)
*/
if (sc->sc_flags & SC_DEBUG)
printf("%s: decompress failed %d\n", ifp->if_xname, rv);
- s = splimp();
+ s = splnet();
sc->sc_flags |= SC_VJ_RESET;
if (rv == DECOMP_ERROR)
sc->sc_flags |= SC_DC_ERROR;
@@ -1364,7 +1364,7 @@ ppp_inproc(sc, m)
*/
if (sc->sc_comp)
sl_uncompress_tcp(NULL, 0, TYPE_ERROR, sc->sc_comp);
- s = splimp();
+ s = splnet();
sc->sc_flags &= ~SC_VJ_RESET;
splx(s);
}
@@ -1522,7 +1522,7 @@ ppp_inproc(sc, m)
/*
* Put the packet on the appropriate input queue.
*/
- s = splimp();
+ s = splnet();
if (IF_QFULL(inq)) {
IF_DROP(inq);
splx(s);
diff --git a/sys/net/if_pppoe.c b/sys/net/if_pppoe.c
index f93a590f574..413e8082dfe 100644
--- a/sys/net/if_pppoe.c
+++ b/sys/net/if_pppoe.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_pppoe.c,v 1.6 2006/01/04 06:04:42 canacar Exp $ */
+/* $OpenBSD: if_pppoe.c,v 1.7 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: if_pppoe.c,v 1.51 2003/11/28 08:56:48 keihan Exp $ */
/*
@@ -259,7 +259,7 @@ pppoe_clone_create(struct if_clone *ifc, int unit)
bpfattach(&sc->sc_sppp.pp_if.if_bpf, &sc->sc_sppp.pp_if, DLT_PPP_ETHER, 0);
#endif
- s = splimp();
+ s = splnet();
LIST_INSERT_HEAD(&pppoe_softc_list, sc, sc_list);
splx(s);
@@ -273,7 +273,7 @@ pppoe_clone_destroy(struct ifnet *ifp)
struct pppoe_softc *sc = ifp->if_softc;
int s;
- s = splimp();
+ s = splnet();
LIST_REMOVE(sc, sc_list);
timeout_del(&sc->sc_timeout);
splx(s);
diff --git a/sys/net/if_tokensubr.c b/sys/net/if_tokensubr.c
index bfb3153af97..40ab41ae933 100644
--- a/sys/net/if_tokensubr.c
+++ b/sys/net/if_tokensubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_tokensubr.c,v 1.20 2005/06/08 06:55:33 henning Exp $ */
+/* $OpenBSD: if_tokensubr.c,v 1.21 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: if_tokensubr.c,v 1.7 1999/05/30 00:39:07 bad Exp $ */
/*
@@ -345,7 +345,7 @@ send:
mflags = m->m_flags;
len = m->m_pkthdr.len;
- s = splimp();
+ s = splnet();
/*
* Queue message on interface, and start output if interface
* not yet active.
@@ -468,7 +468,7 @@ token_input(ifp, m)
return;
}
- s = splimp();
+ s = splnet();
IF_INPUT_ENQUEUE(inq, m);
splx(s);
}
diff --git a/sys/net/if_trunk.c b/sys/net/if_trunk.c
index 63bcce2e330..cbbbff16fb2 100644
--- a/sys/net/if_trunk.c
+++ b/sys/net/if_trunk.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_trunk.c,v 1.20 2006/01/04 17:51:39 brad Exp $ */
+/* $OpenBSD: if_trunk.c,v 1.21 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright (c) 2005 Reyk Floeter <reyk@openbsd.org>
@@ -459,7 +459,7 @@ trunk_port_ioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
struct trunk_port *tp;
int s, error = 0;
- s = splimp();
+ s = splnet();
/* Should be checked by the caller */
if (ifp->if_type != IFT_IEEE8023ADLAG ||
@@ -560,7 +560,7 @@ trunk_ioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
struct ifnet *tpif;
int s, i, error = 0;
- s = splimp();
+ s = splnet();
if ((error = ether_ioctl(ifp, &tr->tr_ac, cmd, data)) > 0)
goto out;
diff --git a/sys/net/if_tun.c b/sys/net/if_tun.c
index 0b4b7176573..56bdc802de4 100644
--- a/sys/net/if_tun.c
+++ b/sys/net/if_tun.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_tun.c,v 1.74 2006/01/11 12:51:33 claudio Exp $ */
+/* $OpenBSD: if_tun.c,v 1.75 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: if_tun.c,v 1.24 1996/05/07 02:40:48 thorpej Exp $ */
/*
@@ -202,7 +202,7 @@ tun_create(struct if_clone *ifc, int unit, int flags)
tp->tun_flags &= ~TUN_LAYER2;
ifp->if_mtu = TUNMTU;
ifp->if_flags = IFF_POINTOPOINT;
- ifp->if_type = IFT_PROPVIRTUAL;
+ ifp->if_type = IFF_POINTOPOINT;
ifp->if_hdrlen = sizeof(u_int32_t);
if_attach(ifp);
if_alloc_sadl(ifp);
@@ -219,7 +219,7 @@ tun_create(struct if_clone *ifc, int unit, int flags)
/* force output function to our function */
ifp->if_output = tun_output;
- s = splimp();
+ s = splnet();
LIST_INSERT_HEAD(&tun_softc_list, tp, tun_list);
splx(s);
@@ -239,7 +239,7 @@ tun_clone_destroy(struct ifnet *ifp)
klist_invalidate(&tp->tun_wsel.si_note);
splx(s);
- s = splimp();
+ s = splnet();
LIST_REMOVE(tp, tun_list);
splx(s);
@@ -330,7 +330,7 @@ tunopen(dev_t dev, int flag, int mode, struct proc *p)
tp->tun_flags |= TUN_OPEN;
/* automatically UP the interface on open */
- s = splimp();
+ s = splnet();
if_up(ifp);
ifp->if_flags |= IFF_RUNNING;
splx(s);
@@ -361,12 +361,12 @@ tunclose(dev_t dev, int flag, int mode, struct proc *p)
/*
* junk all pending output
*/
- s = splimp();
+ s = splnet();
IFQ_PURGE(&ifp->if_snd);
splx(s);
if ((ifp->if_flags & IFF_UP) && !(tp->tun_flags & TUN_STAYUP)) {
- s = splimp();
+ s = splnet();
if_down(ifp);
if (ifp->if_flags & IFF_RUNNING) {
/* find internet addresses and delete routes */
@@ -473,7 +473,7 @@ tun_ioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
struct ifreq *ifr = (struct ifreq *)data;
int error = 0, s;
- s = splimp();
+ s = splnet();
if (tp->tun_flags & TUN_LAYER2)
if ((error = ether_ioctl(ifp, &tp->arpcom, cmd, data)) > 0) {
splx(s);
@@ -596,7 +596,7 @@ tun_output(struct ifnet *ifp, struct mbuf *m0, struct sockaddr *dst,
#endif
len = m0->m_pkthdr.len + sizeof(*af);
- s = splimp();
+ s = splnet();
IFQ_ENQUEUE(&ifp->if_snd, m0, NULL, error);
if (error) {
splx(s);
@@ -639,7 +639,7 @@ tunioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct proc *p)
if ((tp = tun_lookup(minor(dev))) == NULL)
return (ENXIO);
- s = splimp();
+ s = splnet();
switch (cmd) {
case TUNSIFINFO:
tunp = (struct tuninfo *)data;
@@ -754,7 +754,7 @@ tunread(dev_t dev, struct uio *uio, int ioflag)
tp->tun_flags &= ~TUN_RWAIT;
- s = splimp();
+ s = splnet();
do {
while ((tp->tun_flags & TUN_READY) != TUN_READY)
if ((error = tsleep((caddr_t)tp,
@@ -910,7 +910,7 @@ tunwrite(dev_t dev, struct uio *uio, int ioflag)
return (EAFNOSUPPORT);
}
- s = splimp();
+ s = splnet();
if (IF_QFULL(ifq)) {
IF_DROP(ifq);
splx(s);
@@ -946,7 +946,7 @@ tunpoll(dev_t dev, int events, struct proc *p)
ifp = &tp->tun_if;
revents = 0;
- s = splimp();
+ s = splnet();
TUNDEBUG(("%s: tunpoll\n", ifp->if_xname));
if (events & (POLLIN | POLLRDNORM)) {
@@ -988,7 +988,7 @@ tunkqfilter(dev_t dev, struct knote *kn)
ifp = &tp->tun_if;
- s = splimp();
+ s = splnet();
TUNDEBUG(("%s: tunkqfilter\n", ifp->if_xname));
splx(s);
diff --git a/sys/net/pf_ioctl.c b/sys/net/pf_ioctl.c
index 01cddc4a740..ca3674c4ebc 100644
--- a/sys/net/pf_ioctl.c
+++ b/sys/net/pf_ioctl.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pf_ioctl.c,v 1.164 2006/01/06 00:41:21 dhartmei Exp $ */
+/* $OpenBSD: pf_ioctl.c,v 1.165 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright (c) 2001 Daniel Hartmeier
@@ -920,7 +920,7 @@ pf_enable_altq(struct pf_altq *altq)
if (error == 0 && ifp != NULL && ALTQ_IS_ENABLED(&ifp->if_snd)) {
tb.rate = altq->ifbandwidth;
tb.depth = altq->tbrsize;
- s = splimp();
+ s = splnet();
error = tbr_set(&ifp->if_snd, &tb);
splx(s);
}
@@ -950,7 +950,7 @@ pf_disable_altq(struct pf_altq *altq)
if (error == 0) {
/* clear tokenbucket regulator */
tb.rate = 0;
- s = splimp();
+ s = splnet();
error = tbr_set(&ifp->if_snd, &tb);
splx(s);
}
diff --git a/sys/net80211/ieee80211_output.c b/sys/net80211/ieee80211_output.c
index 0ddbeb29311..998f8c7da81 100644
--- a/sys/net80211/ieee80211_output.c
+++ b/sys/net80211/ieee80211_output.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ieee80211_output.c,v 1.15 2006/02/20 20:12:14 damien Exp $ */
+/* $OpenBSD: ieee80211_output.c,v 1.16 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: ieee80211_output.c,v 1.13 2004/05/31 11:02:55 dyoung Exp $ */
/*-
@@ -96,7 +96,7 @@ ieee80211_output(struct ifnet *ifp, struct mbuf *m, struct sockaddr *dst,
* further headers, and start output if interface not
* yet active.
*/
- s = splimp();
+ s = splnet();
IFQ_ENQUEUE(&ifp->if_snd, m, NULL, error);
if (error) {
/* mbuf is already freed */
diff --git a/sys/netatalk/aarp.c b/sys/netatalk/aarp.c
index 9d110728124..e1856fb3d45 100644
--- a/sys/netatalk/aarp.c
+++ b/sys/netatalk/aarp.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: aarp.c,v 1.5 2003/06/06 09:47:21 itojun Exp $ */
+/* $OpenBSD: aarp.c,v 1.6 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright (c) 1990,1991 Regents of The University of Michigan.
@@ -152,7 +152,7 @@ aarptimer(v)
if ( ++aat->aat_timer < (( aat->aat_flags & ATF_COM ) ?
AARPT_KILLC : AARPT_KILLI ))
continue;
- s = splimp();
+ s = splnet();
aarptfree( aat );
splx( s );
}
@@ -291,7 +291,7 @@ aarpresolve( ac, m, destsat, desten )
return( 1 );
}
- s = splimp();
+ s = splnet();
AARPTAB_LOOK( aat, destsat->sat_addr );
if ( aat == 0 ) { /* No entry */
aat = aarptnew( &destsat->sat_addr );
diff --git a/sys/netatalk/at_control.c b/sys/netatalk/at_control.c
index 299826102cb..4bc3e2d8174 100644
--- a/sys/netatalk/at_control.c
+++ b/sys/netatalk/at_control.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: at_control.c,v 1.7 2004/06/21 18:02:20 tholo Exp $ */
+/* $OpenBSD: at_control.c,v 1.8 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright (c) 1990,1991 Regents of The University of Michigan.
@@ -347,7 +347,7 @@ at_ifinit( ifp, aa, sat )
{
struct netrange nr, onr;
struct sockaddr_at oldaddr;
- int s = splimp(), error = 0, i, j, netinc, nodeinc, nnets;
+ int s = splnet(), error = 0, i, j, netinc, nodeinc, nnets;
u_int16_t net;
oldaddr = aa->aa_addr;
diff --git a/sys/netatalk/ddp_input.c b/sys/netatalk/ddp_input.c
index 7bede92b0cb..57d1164b783 100644
--- a/sys/netatalk/ddp_input.c
+++ b/sys/netatalk/ddp_input.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ddp_input.c,v 1.3 2002/03/14 01:27:10 millert Exp $ */
+/* $OpenBSD: ddp_input.c,v 1.4 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright (c) 1990,1994 Regents of The University of Michigan.
@@ -100,7 +100,7 @@ atintr()
int s;
for (;;) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE( &atintrq2, m );
@@ -125,7 +125,7 @@ atintr()
}
for (;;) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE( &atintrq1, m );
diff --git a/sys/netbt/bt_input.c b/sys/netbt/bt_input.c
index a6622342d40..3584f194603 100644
--- a/sys/netbt/bt_input.c
+++ b/sys/netbt/bt_input.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: bt_input.c,v 1.1 2005/01/14 12:04:02 grange Exp $ */
+/* $OpenBSD: bt_input.c,v 1.2 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright (c) 2004 Alexander Yurchenko <grange@openbsd.org>
*
@@ -46,7 +46,7 @@ btintr(void)
int s;
for (;;) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&btintrq, m);
splx(s);
diff --git a/sys/netbt/hci_raw.c b/sys/netbt/hci_raw.c
index 1b29f736798..0feb03763a5 100644
--- a/sys/netbt/hci_raw.c
+++ b/sys/netbt/hci_raw.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: hci_raw.c,v 1.3 2005/01/17 18:12:49 mickey Exp $ */
+/* $OpenBSD: hci_raw.c,v 1.4 2006/03/04 22:40:16 brad Exp $ */
/*
* ng_btsocket_hci_raw.c
@@ -338,7 +338,7 @@ ng_btsocket_hci_raw_node_rcvdata(struct ifnet *ifp, struct mbuf *m)
NG_BT_ITEMQ_ENQUEUE(&ng_btsocket_hci_raw_queue, item);
error = ng_btsocket_hci_raw_wakeup_input_task();
#endif
- s = splimp();
+ s = splnet();
IF_INPUT_ENQUEUE(&btintrq, nam);
splx(s);
schednetisr(NETISR_BT);
@@ -697,7 +697,7 @@ ng_btsocket_hci_raw_output(void *arg1, int arg2)
continue;
if (strcmp(sa->hci_node, ifp->if_xname) == 0) {
- s = splimp();
+ s = splnet();
IFQ_ENQUEUE(&ifp->if_snd, m, NULL, error);
if (error) {
splx(s);
diff --git a/sys/netinet/if_ether.c b/sys/netinet/if_ether.c
index 4bd58fa0e4f..74b5a5b5825 100644
--- a/sys/netinet/if_ether.c
+++ b/sys/netinet/if_ether.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_ether.c,v 1.61 2005/11/29 02:59:42 jolan Exp $ */
+/* $OpenBSD: if_ether.c,v 1.62 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: if_ether.c,v 1.31 1996/05/11 12:59:58 mycroft Exp $ */
/*
@@ -464,7 +464,7 @@ arpintr()
int s, len;
while (arpintrq.ifq_head) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&arpintrq, m);
splx(s);
if (m == 0 || (m->m_flags & M_PKTHDR) == 0)
diff --git a/sys/netinet/in.c b/sys/netinet/in.c
index 4e9f456bb86..ed48a712707 100644
--- a/sys/netinet/in.c
+++ b/sys/netinet/in.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: in.c,v 1.42 2006/02/21 15:33:59 claudio Exp $ */
+/* $OpenBSD: in.c,v 1.43 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: in.c,v 1.26 1996/02/13 23:41:39 christos Exp $ */
/*
@@ -674,7 +674,7 @@ in_ifinit(ifp, ia, sin, scrub)
{
u_int32_t i = sin->sin_addr.s_addr;
struct sockaddr_in oldaddr;
- int s = splimp(), flags = RTF_UP, error;
+ int s = splnet(), flags = RTF_UP, error;
oldaddr = ia->ia_addr;
ia->ia_addr = *sin;
diff --git a/sys/netinet/ip_gre.c b/sys/netinet/ip_gre.c
index 886964f2070..d6948648d25 100644
--- a/sys/netinet/ip_gre.c
+++ b/sys/netinet/ip_gre.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip_gre.c,v 1.27 2005/07/31 03:52:19 pascoe Exp $ */
+/* $OpenBSD: ip_gre.c,v 1.28 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: ip_gre.c,v 1.9 1999/10/25 19:18:11 drochner Exp $ */
/*
@@ -196,7 +196,7 @@ gre_input2(m , hlen, proto)
bpf_mtap_af(sc->sc_if.if_bpf, af, m);
#endif
- s = splimp(); /* possible */
+ s = splnet(); /* possible */
IF_INPUT_ENQUEUE(ifq, m);
splx(s);
@@ -322,7 +322,7 @@ gre_mobile_input(struct mbuf *m, ...)
bpf_mtap_af(sc->sc_if.if_bpf, AF_INET, m);
#endif
- s = splimp(); /* possible */
+ s = splnet(); /* possible */
IF_INPUT_ENQUEUE(ifq, m);
splx(s);
}
diff --git a/sys/netinet/ip_input.c b/sys/netinet/ip_input.c
index d6ca6ad4b5e..e77bee09577 100644
--- a/sys/netinet/ip_input.c
+++ b/sys/netinet/ip_input.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip_input.c,v 1.136 2006/01/03 14:53:50 mpf Exp $ */
+/* $OpenBSD: ip_input.c,v 1.137 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: ip_input.c,v 1.30 1996/03/16 23:53:58 christos Exp $ */
/*
@@ -249,7 +249,7 @@ ipintr()
* Get next datagram off input queue and get IP header
* in first mbuf.
*/
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&ipintrq, m);
splx(s);
if (m == 0)
diff --git a/sys/netinet/ip_ipip.c b/sys/netinet/ip_ipip.c
index e121ece0c3e..9b6fd0c5615 100644
--- a/sys/netinet/ip_ipip.c
+++ b/sys/netinet/ip_ipip.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip_ipip.c,v 1.33 2005/07/31 03:52:19 pascoe Exp $ */
+/* $OpenBSD: ip_ipip.c,v 1.34 2006/03/04 22:40:16 brad Exp $ */
/*
* The authors of this code are John Ioannidis (ji@tla.org),
* Angelos D. Keromytis (kermit@csd.uch.gr) and
@@ -365,7 +365,7 @@ ipip_input(struct mbuf *m, int iphlen, struct ifnet *gifp)
m);
#endif
- s = splimp(); /* isn't it already? */
+ s = splnet(); /* isn't it already? */
if (IF_QFULL(ifq)) {
IF_DROP(ifq);
m_freem(m);
diff --git a/sys/netinet/ip_output.c b/sys/netinet/ip_output.c
index dae7a979b9e..36fde452909 100644
--- a/sys/netinet/ip_output.c
+++ b/sys/netinet/ip_output.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip_output.c,v 1.173 2005/10/05 17:32:22 norby Exp $ */
+/* $OpenBSD: ip_output.c,v 1.174 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: ip_output.c,v 1.28 1996/02/13 23:43:07 christos Exp $ */
/*
@@ -1978,7 +1978,7 @@ in_delayed_cksum(struct mbuf *m)
ip = mtod(m, struct ip *);
offset = ip->ip_hl << 2;
csum = in4_cksum(m, 0, offset, m->m_pkthdr.len - offset);
- if (csum == 0 && ip->ip_p == IPPROTO_UDP)
+ if (csum == 0 && (m->m_pkthdr.csum_flags & M_UDPV4_CSUM_OUT) != 0)
csum = 0xffff;
switch (ip->ip_p) {
diff --git a/sys/netinet/ipsec_input.c b/sys/netinet/ipsec_input.c
index aaddbf4a778..84292f88471 100644
--- a/sys/netinet/ipsec_input.c
+++ b/sys/netinet/ipsec_input.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ipsec_input.c,v 1.77 2006/01/13 10:11:23 mpf Exp $ */
+/* $OpenBSD: ipsec_input.c,v 1.78 2006/03/04 22:40:16 brad Exp $ */
/*
* The authors of this code are John Ioannidis (ji@tla.org),
* Angelos D. Keromytis (kermit@csd.uch.gr) and
@@ -676,7 +676,7 @@ int
ah4_input_cb(struct mbuf *m, ...)
{
struct ifqueue *ifq = &ipintrq;
- int s = splimp();
+ int s = splnet();
/*
* Interface pointer is already in first mbuf; chop off the
@@ -731,7 +731,7 @@ int
esp4_input_cb(struct mbuf *m, ...)
{
struct ifqueue *ifq = &ipintrq;
- int s = splimp();
+ int s = splnet();
/*
* Interface pointer is already in first mbuf; chop off the
@@ -773,7 +773,7 @@ int
ipcomp4_input_cb(struct mbuf *m, ...)
{
struct ifqueue *ifq = &ipintrq;
- int s = splimp();
+ int s = splnet();
/*
* Interface pointer is already in first mbuf; chop off the
diff --git a/sys/netinet/tcp_subr.c b/sys/netinet/tcp_subr.c
index bea45d5015b..13dc5c7ec40 100644
--- a/sys/netinet/tcp_subr.c
+++ b/sys/netinet/tcp_subr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: tcp_subr.c,v 1.92 2005/09/28 15:20:12 brad Exp $ */
+/* $OpenBSD: tcp_subr.c,v 1.93 2006/03/04 22:40:16 brad Exp $ */
/* $NetBSD: tcp_subr.c,v 1.22 1996/02/13 23:44:00 christos Exp $ */
/*
@@ -626,7 +626,7 @@ tcp_drain()
{
struct inpcb *inp;
- /* called at splimp() */
+ /* called at splnet() */
CIRCLEQ_FOREACH(inp, &tcbtable.inpt_queue, inp_queue) {
struct tcpcb *tp = (struct tcpcb *)inp->inp_ppcb;
diff --git a/sys/netinet6/in6.c b/sys/netinet6/in6.c
index 89f4f33b0b5..61fb740b1f2 100644
--- a/sys/netinet6/in6.c
+++ b/sys/netinet6/in6.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: in6.c,v 1.62 2006/02/14 10:34:31 otto Exp $ */
+/* $OpenBSD: in6.c,v 1.63 2006/03/04 22:40:16 brad Exp $ */
/* $KAME: in6.c,v 1.372 2004/06/14 08:14:21 itojun Exp $ */
/*
@@ -1588,7 +1588,7 @@ in6_ifinit(ifp, ia, sin6, newhost)
int newhost;
{
int error = 0, plen, ifacount = 0;
- int s = splimp();
+ int s = splnet();
struct ifaddr *ifa;
/*
diff --git a/sys/netinet6/ip6_input.c b/sys/netinet6/ip6_input.c
index 64b797e37ef..d3920a83809 100644
--- a/sys/netinet6/ip6_input.c
+++ b/sys/netinet6/ip6_input.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip6_input.c,v 1.62 2005/08/11 12:55:31 mpf Exp $ */
+/* $OpenBSD: ip6_input.c,v 1.63 2006/03/04 22:40:16 brad Exp $ */
/* $KAME: ip6_input.c,v 1.188 2001/03/29 05:34:31 itojun Exp $ */
/*
@@ -175,7 +175,7 @@ ip6intr()
struct mbuf *m;
for (;;) {
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&ip6intrq, m);
splx(s);
if (m == 0)
diff --git a/sys/netipx/ipx.c b/sys/netipx/ipx.c
index c481cf017df..edd7dc7d378 100644
--- a/sys/netipx/ipx.c
+++ b/sys/netipx/ipx.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ipx.c,v 1.12 2003/12/10 07:22:43 itojun Exp $ */
+/* $OpenBSD: ipx.c,v 1.13 2006/03/04 22:40:16 brad Exp $ */
/*-
*
@@ -235,7 +235,7 @@ ipx_ifinit(ifp, ia, sipx, scrub)
int scrub;
{
struct sockaddr_ipx oldaddr;
- int s = splimp(), error;
+ int s = splnet(), error;
/*
* Set up new addresses.
diff --git a/sys/netipx/ipx_input.c b/sys/netipx/ipx_input.c
index efd4ce9af9f..658e8b62411 100644
--- a/sys/netipx/ipx_input.c
+++ b/sys/netipx/ipx_input.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ipx_input.c,v 1.19 2004/06/20 21:33:00 tholo Exp $ */
+/* $OpenBSD: ipx_input.c,v 1.20 2006/03/04 22:40:16 brad Exp $ */
/*-
*
@@ -129,7 +129,7 @@ next:
* Get next datagram off input queue and get IPX header
* in first mbuf.
*/
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&ipxintrq, m);
splx(s);
if (m == NULL) {
diff --git a/sys/netipx/ipx_ip.c b/sys/netipx/ipx_ip.c
index c2257d58cbd..dc20cf5f639 100644
--- a/sys/netipx/ipx_ip.c
+++ b/sys/netipx/ipx_ip.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ipx_ip.c,v 1.19 2004/09/20 23:10:47 drahn Exp $ */
+/* $OpenBSD: ipx_ip.c,v 1.20 2006/03/04 22:40:16 brad Exp $ */
/*-
*
@@ -223,7 +223,7 @@ ipxip_input( struct mbuf *m, ...)
/*
* Deliver to IPX
*/
- s = splimp();
+ s = splnet();
if (IF_QFULL(ifq)) {
IF_DROP(ifq);
m_freem(m);
diff --git a/sys/netipx/ipx_pcb.c b/sys/netipx/ipx_pcb.c
index 929498843ca..48315371754 100644
--- a/sys/netipx/ipx_pcb.c
+++ b/sys/netipx/ipx_pcb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ipx_pcb.c,v 1.10 2003/12/10 07:22:43 itojun Exp $ */
+/* $OpenBSD: ipx_pcb.c,v 1.11 2006/03/04 22:40:16 brad Exp $ */
/*-
*
@@ -317,7 +317,7 @@ ipx_pcbnotify(dst, errno, notify, param)
long param;
{
struct ipxpcb *ipxp, *oinp;
- int s = splimp();
+ int s = splnet();
for (ipxp = ipxcbtable.ipxpt_queue.cqh_first;
ipxp != (struct ipxpcb *)&ipxcbtable.ipxpt_queue;) {
diff --git a/sys/netnatm/natm.c b/sys/netnatm/natm.c
index e3f6a5f8f88..8022034e207 100644
--- a/sys/netnatm/natm.c
+++ b/sys/netnatm/natm.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: natm.c,v 1.6 2001/05/16 12:54:08 ho Exp $ */
+/* $OpenBSD: natm.c,v 1.7 2006/03/04 22:40:16 brad Exp $ */
/*
*
@@ -188,7 +188,7 @@ struct proc *p;
ATM_PH_VPI(&api.aph) = npcb->npcb_vpi;
ATM_PH_SETVCI(&api.aph, npcb->npcb_vci);
api.rxhand = npcb;
- s2 = splimp();
+ s2 = splnet();
if (ifp->if_ioctl == NULL ||
ifp->if_ioctl(ifp, SIOCATMENA, (caddr_t) &api) != 0) {
splx(s2);
@@ -219,7 +219,7 @@ struct proc *p;
ATM_PH_VPI(&api.aph) = npcb->npcb_vpi;
ATM_PH_SETVCI(&api.aph, npcb->npcb_vci);
api.rxhand = npcb;
- s2 = splimp();
+ s2 = splnet();
if (ifp->if_ioctl != NULL)
ifp->if_ioctl(ifp, SIOCATMDIS, (caddr_t) &api);
splx(s);
@@ -347,7 +347,7 @@ natmintr()
struct natmpcb *npcb;
next:
- s = splimp();
+ s = splnet();
IF_DEQUEUE(&natmintrq, m);
splx(s);
if (m == NULL)
@@ -361,7 +361,7 @@ next:
npcb = (struct natmpcb *) m->m_pkthdr.rcvif; /* XXX: overloaded */
so = npcb->npcb_socket;
- s = splimp(); /* could have atm devs @ different levels */
+ s = splnet(); /* could have atm devs @ different levels */
npcb->npcb_inq--;
splx(s);
diff --git a/sys/netnatm/natm_pcb.c b/sys/netnatm/natm_pcb.c
index 8ed4e11eeb9..fdb406f8bc8 100644
--- a/sys/netnatm/natm_pcb.c
+++ b/sys/netnatm/natm_pcb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: natm_pcb.c,v 1.5 2002/03/14 01:27:12 millert Exp $ */
+/* $OpenBSD: natm_pcb.c,v 1.6 2006/03/04 22:40:16 brad Exp $ */
/*
*
@@ -85,7 +85,7 @@ struct natmpcb *npcb;
int op;
{
- int s = splimp();
+ int s = splnet();
if ((npcb->npcb_flags & NPCB_FREE) == 0) {
LIST_REMOVE(npcb, pcblist);
@@ -117,7 +117,7 @@ u_int8_t vpi;
{
struct natmpcb *cpcb = NULL; /* current pcb */
- int s = splimp();
+ int s = splnet();
/*
diff --git a/sys/altq/altq_cbq.c b/sys/altq/altq_cbq.c
index d3ec56199f2..902ed7bde6e 100644
--- a/sys/altq/altq_cbq.c
+++ b/sys/altq/altq_cbq.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: altq_cbq.c,v 1.19 2005/10/17 08:43:35 henning Exp $ */
+/* $OpenBSD: altq_cbq.c,v 1.20 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: altq_cbq.c,v 1.9 2000/12/14 08:12:45 thorpej Exp $ */
/*
@@ -195,7 +195,7 @@ cbq_pfattach(struct pf_altq *a)
if ((ifp = ifunit(a->ifname)) == NULL || a->altq_disc == NULL)
return (EINVAL);
- s = splimp();
+ s = splnet();
error = altq_attach(&ifp->if_snd, ALTQT_CBQ, a->altq_disc,
cbq_enqueue, cbq_dequeue, cbq_request, NULL, NULL);
splx(s);
@@ -430,7 +430,7 @@ cbq_getqstats(struct pf_altq *a, void *ubuf, int *nbytes)
* layer (e.g. ether_output). cbq_enqueue queues the given packet
* to the cbq, then invokes the driver's start routine.
*
* Assumptions: called in splimp
* Returns: 0 if the queueing is successful.
* ENOBUFS if a packet dropping occurred as a result of
* the queueing.
@@ -497,7 +497,7 @@ cbq_dequeue(struct ifaltq *ifq, int op)
/*
* void
* cbqrestart(queue_t *) - Restart sending of data.
* called from rmc_restart in splimp via timeout after waking up
* a suspended class.
* Returns: NONE
*/
@@ -430,7 +430,7 @@ cbq_getqstats(struct pf_altq *a, void *ubuf, int *nbytes)
* to the cbq, then invokes the driver's start routine.
*
- * Assumptions: called in splimp
+ * Assumptions: called in splnet
* Returns: 0 if the queueing is successful.
* ENOBUFS if a packet dropping occurred as a result of
@@ -497,7 +497,7 @@ cbq_dequeue(struct ifaltq *ifq, int op)
* void
* cbqrestart(queue_t *) - Restart sending of data.
- * called from rmc_restart in splimp via timeout after waking up
+ * called from rmc_restart in splnet via timeout after waking up
* a suspended class.
* Returns: NONE
diff --git a/sys/altq/altq_rmclass.c b/sys/altq/altq_rmclass.c
index 9495742fb91..6f4c6bdbaa2 100644
--- a/sys/altq/altq_rmclass.c
+++ b/sys/altq/altq_rmclass.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: altq_rmclass.c,v 1.11 2003/10/17 19:13:01 henning Exp $ */
+/* $OpenBSD: altq_rmclass.c,v 1.12 2006/03/04 22:40:15 brad Exp $ */
/* $KAME: altq_rmclass.c,v 1.10 2001/02/09 07:20:40 kjc Exp $ */
/*
@@ -291,7 +291,7 @@ rmc_newclass(int pri, struct rm_ifdat *ifd, u_int nsecPerByte,
/*
* put the class into the class tree
*/
- s = splimp();
+ s = splnet();
if ((peer = ifd->active_[pri]) != NULL) {
/* find the last class at this pri */
cl->peer_ = peer;
@@ -338,7 +338,7 @@ rmc_modclass(struct rm_class *cl, u_int nsecPerByte, int maxq, u_int maxidle,
ifd = cl->ifdat_;
old_allotment = cl->allotment_;
- s = splimp();
+ s = splnet();
cl->allotment_ = RM_NS_PER_SEC / nsecPerByte; /* Bytes per sec */
cl->qthresh_ = 0;
cl->ns_per_byte_ = nsecPerByte;
@@ -532,7 +532,7 @@ rmc_delete_class(struct rm_ifdat *ifd, struct rm_class *cl)
if (cl->sleeping_)
CALLOUT_STOP(&cl->callout_);
- s = splimp();
+ s = splnet();
/*
* Free packets in the packet queue.
* XXX - this may not be a desired behavior. Packets should be
@@ -1506,7 +1506,7 @@ rmc_delay_action(struct rm_class *cl, struct rm_class *borrow)
* responsible for locking but this is the only routine that is not
* called directly or indirectly from the interface driver so it has
* know about system locking conventions. Under bsd, locking is done
* by raising IPL to splimp so that's what's implemented here. On a
* different system this would probably need to be changed.
*
* Returns: NONE
@@ -1518,7 +1518,7 @@ rmc_restart(struct rm_class *cl)
struct rm_ifdat *ifd = cl->ifdat_;
int s;
- s = splimp();
+ s = splnet();
if (cl->sleeping_) {
cl->sleeping_ = 0;
cl->undertime_.tv_sec = 0;
@@ -1506,7 +1506,7 @@ rmc_delay_action(struct rm_class *cl, struct rm_class *borrow)
* called directly or indirectly from the interface driver so it has
* know about system locking conventions. Under bsd, locking is done
- * by raising IPL to splimp so that's what's implemented here. On a
+ * by raising IPL to splnet so that's what's implemented here. On a
* different system this would probably need to be changed.
*
diff --git a/sys/net/bpf.c b/sys/net/bpf.c
index c7ff40f28f6..b8c3447a68c 100644
--- a/sys/net/bpf.c
+++ b/sys/net/bpf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: bpf.c,v 1.60 2005/11/03 20:00:18 reyk Exp $ */
+/* $OpenBSD: bpf.c,v 1.61 2006/03/04 22:40:15 brad Exp $ */
/* $NetBSD: bpf.c,v 1.33 1997/02/21 23:59:35 thorpej Exp $ */
/*
@@ -235,7 +235,7 @@ bpf_movein(struct uio *uio, u_int linktype, struct mbuf **mp,
/*
* Attach file to the bpf interface, i.e. make d listen on bp.
* Must be called at splimp.
*/
void
bpf_attachd(struct bpf_d *d, struct bpf_if *bp)
@@ -363,7 +363,7 @@ bpfclose(dev_t dev, int flag, int mode, struct proc *p)
int s;
d = bpfilter_lookup(minor(dev));
- s = splimp();
+ s = splnet();
if (d->bd_bif)
bpf_detachd(d);
bpf_wakeup(d);
@@ -405,7 +405,7 @@ bpfread(dev_t dev, struct uio *uio, int ioflag)
if (uio->uio_resid != d->bd_bufsize)
return (EINVAL);
- s = splimp();
+ s = splnet();
D_GET(d);
@@ -494,7 +494,7 @@ bpfread(dev_t dev, struct uio *uio, int ioflag)
*/
error = uiomove(d->bd_hbuf, d->bd_hlen, uio);
- s = splimp();
+ s = splnet();
d->bd_fbuf = d->bd_hbuf;
d->bd_hbuf = 0;
d->bd_hlen = 0;
@@ -569,7 +569,7 @@ bpfwrite(dev_t dev, struct uio *uio, int ioflag)
/*
* Reset a descriptor by flushing its packet buffer and clearing the
* receive and drop counts. Should be called at splimp.
*/
void
bpf_reset_d(struct bpf_d *d)
@@ -649,7 +649,7 @@ bpfioctl(dev_t dev, u_long cmd, caddr_t addr, int flag, struct proc *p)
{
int n;
- s = splimp();
+ s = splnet();
n = d->bd_slen;
if (d->bd_hbuf)
n += d->bd_hlen;
@@ -701,7 +701,7 @@ bpfioctl(dev_t dev, u_long cmd, caddr_t addr, int flag, struct proc *p)
* Flush read packet buffer.
*/
case BIOCFLUSH:
- s = splimp();
+ s = splnet();
bpf_reset_d(d);
splx(s);
break;
@@ -717,7 +717,7 @@ bpfioctl(dev_t dev, u_long cmd, caddr_t addr, int flag, struct proc *p)
error = EINVAL;
break;
}
- s = splimp();
+ s = splnet();
if (d->bd_promisc == 0) {
error = ifpromisc(d->bd_bif->bif_ifp, 1);
if (error == 0)
@@ -910,7 +910,7 @@ bpf_setf(struct bpf_d *d, struct bpf_program *fp, int wf)
if (fp->bf_insns == 0) {
if (fp->bf_len != 0)
return (EINVAL);
- s = splimp();
+ s = splnet();
if (wf)
d->bd_wfilter = 0;
else
@@ -929,7 +929,7 @@ bpf_setf(struct bpf_d *d, struct bpf_program *fp, int wf)
fcode = (struct bpf_insn *)malloc(size, M_DEVBUF, M_WAITOK);
if (copyin((caddr_t)fp->bf_insns, (caddr_t)fcode, size) == 0 &&
bpf_validate(fcode, (int)flen)) {
- s = splimp();
+ s = splnet();
if (wf)
d->bd_wfilter = fcode;
else
@@ -984,7 +984,7 @@ bpf_setif(struct bpf_d *d, struct ifreq *ifr)
if (error != 0)
return (error);
}
- s = splimp();
+ s = splnet();
if (candidate != d->bd_bif) {
if (d->bd_bif)
/*
@@ -1028,7 +1028,7 @@ bpfpoll(dev_t dev, int events, struct proc *p)
* An imitation of the FIONREAD ioctl code.
*/
d = bpfilter_lookup(minor(dev));
- s = splimp();
+ s = splnet();
if (d->bd_hlen == 0 && (!d->bd_immediate || d->bd_slen == 0)) {
revents = 0; /* no data waiting */
/*
@@ -1064,7 +1064,7 @@ bpfkqfilter(dev_t dev, struct knote *kn)
kn->kn_hook = (caddr_t)((u_long)dev);
- s = splimp();
+ s = splnet();
SLIST_INSERT_HEAD(klist, kn, kn_selnext);
splx(s);
@@ -1079,7 +1079,7 @@ filt_bpfrdetach(struct knote *kn)
int s;
d = bpfilter_lookup(minor(dev));
- s = splimp();
+ s = splnet();
SLIST_REMOVE(&d->bd_sel.si_note, kn, knote, kn_selnext);
splx(s);
}
@@ -1555,7 +1555,7 @@ bpf_setdlt(struct bpf_d *d, u_int dlt)
}
if (bp == NULL)
return (EINVAL);
- s = splimp();
+ s = splnet();
bpf_detachd(d);
bpf_attachd(d, bp);
bpf_reset_d(d);
@@ -235,7 +235,7 @@ bpf_movein(struct uio *uio, u_int linktype, struct mbuf **mp,
/*
* Attach file to the bpf interface, i.e. make d listen on bp.
- * Must be called at splimp.
+ * Must be called at splnet.
*/
void
@@ -569,7 +569,7 @@ bpfwrite(dev_t dev, struct uio *uio, int ioflag)
/*
* Reset a descriptor by flushing its packet buffer and clearing the
- * receive and drop counts. Should be called at splimp.
+ * receive and drop counts. Should be called at splnet.
*/
void
diff --git a/sys/net/if_spppsubr.c b/sys/net/if_spppsubr.c
index a61cafeece3..0edd3d7edd7 100644
--- a/sys/net/if_spppsubr.c
+++ b/sys/net/if_spppsubr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_spppsubr.c,v 1.38 2006/02/24 20:34:34 claudio Exp $ */
+/* $OpenBSD: if_spppsubr.c,v 1.39 2006/03/04 22:40:16 brad Exp $ */
/*
* Synchronous PPP/Cisco link level subroutines.
* Keepalive protocol implemented in both Cisco and PPP modes.
@@ -613,7 +613,7 @@ sppp_input(struct ifnet *ifp, struct mbuf *m)
goto drop;
/* Check queue. */
- s = splimp();
+ s = splnet();
if (IF_QFULL (inq)) {
/* Queue overflow. */
IF_DROP(inq);
@@ -643,7 +643,7 @@ sppp_output(struct ifnet *ifp, struct mbuf *m,
int s, len, rv = 0;
u_int16_t protocol;
- s = splimp();
+ s = splnet();
getmicrouptime(&tv);
sp->pp_last_activity = tv.tv_sec;
@@ -663,7 +663,7 @@ sppp_output(struct ifnet *ifp, struct mbuf *m,
ifp->if_flags |= IFF_RUNNING;
splx(s);
lcp.Open(sp);
- s = splimp();
+ s = splnet();
}
#ifdef INET
@@ -914,7 +914,7 @@ sppp_isempty(struct ifnet *ifp)
struct sppp *sp = (struct sppp*) ifp;
int empty, s;
- s = splimp();
+ s = splnet();
empty = !sp->pp_fastq.ifq_head && !sp->pp_cpq.ifq_head &&
IFQ_IS_EMPTY(&sp->pp_if.if_snd);
splx(s);
@@ -931,7 +931,7 @@ sppp_dequeue(struct ifnet *ifp)
struct mbuf *m;
int s;
- s = splimp();
+ s = splnet();
/*
* Process only the control protocol queue until we have at
* least one NCP open.
@@ -959,8 +959,7 @@ sppp_pick(struct ifnet *ifp)
struct mbuf *m;
int s;
- s= splimp ();
-
+ s = splnet();
m = sp->pp_cpq.ifq_head;
if (m == NULL &&
(sp->pp_phase == PHASE_NETWORK ||
@@ -981,7 +980,7 @@ sppp_ioctl(struct ifnet *ifp, u_long cmd, void *data)
struct sppp *sp = (struct sppp*) ifp;
int s, rv, going_up, going_down, newmode;
- s = splimp();
+ s = splnet();
rv = 0;
switch (cmd) {
case SIOCAIFADDR:
@@ -1787,7 +1786,7 @@ sppp_to_event(const struct cp *cp, struct sppp *sp)
STDDCL;
int s;
- s = splimp();
+ s = splnet();
if (debug)
log(LOG_DEBUG, SPP_FMT "%s TO(%s) rst_counter = %d\n",
SPP_ARGS(ifp), cp->name,
@@ -3137,7 +3136,7 @@ sppp_chap_input(struct sppp *sp, struct mbuf *m)
}
addlog("\n");
}
- x = splimp();
+ x = splnet();
sp->pp_flags &= ~PP_NEEDAUTH;
if (sp->myauth.proto == PPP_CHAP &&
(sp->lcp.opts & (1 << LCP_OPT_AUTH_PROTO)) &&
@@ -3316,7 +3315,7 @@ sppp_chap_TO(void *cookie)
STDDCL;
int s;
- s = splimp();
+ s = splnet();
if (debug)
log(LOG_DEBUG, SPP_FMT "chap TO(%s) rst_counter = %d\n",
SPP_ARGS(ifp),
@@ -3389,7 +3388,7 @@ sppp_chap_tlu(struct sppp *sp)
addlog("re-challenging supressed\n");
}
- x = splimp();
+ x = splnet();
/* indicate to LCP that we need to be closed down */
sp->lcp.protos |= (1 << IDX_CHAP);
@@ -3557,7 +3556,7 @@ sppp_pap_input(struct sppp *sp, struct mbuf *m)
}
addlog("\n");
}
- x = splimp();
+ x = splnet();
sp->pp_flags &= ~PP_NEEDAUTH;
if (sp->myauth.proto == PPP_PAP &&
(sp->lcp.opts & (1 << LCP_OPT_AUTH_PROTO)) &&
@@ -3659,7 +3658,7 @@ sppp_pap_TO(void *cookie)
STDDCL;
int s;
- s = splimp();
+ s = splnet();
if (debug)
log(LOG_DEBUG, SPP_FMT "pap TO(%s) rst_counter = %d\n",
SPP_ARGS(ifp),
@@ -3716,7 +3715,7 @@ sppp_pap_tlu(struct sppp *sp)
log(LOG_DEBUG, SPP_FMT "%s tlu\n",
SPP_ARGS(ifp), pap.name);
- x = splimp();
+ x = splnet();
/* indicate to LCP that we need to be closed down */
sp->lcp.protos |= (1 << IDX_PAP);
@@ -3883,7 +3882,7 @@ sppp_keepalive(void *dummy)
int s;
struct timeval tv;
- s = splimp();
+ s = splnet();
getmicrouptime(&tv);
for (sp=spppq; sp; sp=sp->pp_next) {
struct ifnet *ifp = &sp->pp_if;
@@ -3997,7 +3996,7 @@ sppp_get_ip_addrs(struct sppp *sp, u_long *src, u_long *dst, u_long *srcmask)
}
/*
* Set my IP address. Must be called at splimp.
*/
HIDE void
sppp_set_ip_addr(struct sppp *sp, u_long src)
@@ -3997,7 +3996,7 @@ sppp_get_ip_addrs(struct sppp *sp, u_long *src, u_long *dst, u_long *srcmask)
}
/*
- * Set my IP address. Must be called at splimp.
+ * Set my IP address. Must be called at splnet.
*/
HIDE void
diff --git a/sys/net/if_vlan.c b/sys/net/if_vlan.c
index c47b3178c6c..cbece492c66 100644
--- a/sys/net/if_vlan.c
+++ b/sys/net/if_vlan.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_vlan.c,v 1.63 2006/02/09 00:05:55 reyk Exp $ */
+/* $OpenBSD: if_vlan.c,v 1.64 2006/03/04 22:40:16 brad Exp $ */
/*
* Copyright 1998 Massachusetts Institute of Technology
@@ -246,7 +246,7 @@ vlan_start(struct ifnet *ifp)
/*
* Send it, precisely as ether_output() would have.
* We are already running at splimp.
*/
p->if_obytes += m->m_pkthdr.len;
if (m->m_flags & M_MCAST)
@@ -565,7 +565,7 @@ vlan_ioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
if ((error = copyin(ifr->ifr_data, &vlr, sizeof vlr)))
break;
if (vlr.vlr_parent[0] == '\0') {
- s = splimp();
+ s = splnet();
vlan_unconfig(ifp);
if (ifp->if_flags & IFF_UP)
if_down(ifp);
@@ -645,6 +645,7 @@ vlan_ioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
if (ifv->ifv_p != NULL)
error = vlan_set_promisc(ifp);
break;
+
case SIOCADDMULTI:
error = (ifv->ifv_p != NULL) ?
vlan_ether_addmulti(ifv, ifr) : EINVAL;
@@ -246,7 +246,7 @@ vlan_start(struct ifnet *ifp)
/*
* Send it, precisely as ether_output() would have.
- * We are already running at splimp.
+ * We are already running at splnet.
*/
p->if_obytes += m->m_pkthdr.len;